"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const __1 = require("..");
const utils_1 = require("./utils");
describe("decode", () => {
    // This fixtures is a 32w, 16h rectangle with RGB = (255, 128, 64) and no alpha channel.
    const someOrangeRectangle = fs_1.readFileSync(`${__dirname}/fixtures/orange-rectangle.png`);
    // This fixtures is a 32w, 16h rectangle with RGBA = (255, 128, 64, 128).
    const someOpaqueRectangle = fs_1.readFileSync(`${__dirname}/fixtures/opaque-rectangle.png`);
    it("decodes a png", () => {
        const decoded = __1.decode(someOrangeRectangle).data;
        // 32w * 16h * 3 bytes per pixel.
        const expectedLength = 32 * 16 * 3;
        expect(decoded.length).toBe(expectedLength);
        utils_1.expectEveryPixel(decoded, [255, 128, 64]);
    });
    it("decodes a png with an alpha channel", () => {
        const decoded = __1.decode(someOpaqueRectangle).data;
        // 32w * 16h * 4 bytes per pixel.
        const expectedLength = 32 * 16 * 4;
        expect(decoded.length).toBe(expectedLength);
        utils_1.expectEveryPixel(decoded, [255, 128, 64, 127]);
    });
    it("throws an error when trying to decode something which isn't a buffer", () => {
        expect(() => __1.decode("something")).toThrowErrorMatchingSnapshot();
    });
});
describe("readPngFileSync", () => {
    it("decodes a PNG file", () => {
        utils_1.expectEveryPixel(__1.readPngFileSync(`${__dirname}/fixtures/orange-rectangle.png`).data, [255, 128, 64]);
    });
});
describe("readPngFile", () => {
    describe("using the Promise API", () => {
        it("decodes a PNG file", () => __awaiter(void 0, void 0, void 0, function* () {
            const decoded = (yield __1.readPngFile(`${__dirname}/fixtures/orange-rectangle.png`)).data;
            utils_1.expectEveryPixel(decoded, [255, 128, 64]);
        }));
        it("rejects with an error when decoding failed", () => __awaiter(void 0, void 0, void 0, function* () {
            return expect(__1.readPngFile(`${__dirname}/fixtures/red-blue-gradient-256px.jpg`)).rejects.toMatchSnapshot();
        }));
        it("rejects with an error when reading failed", () => __awaiter(void 0, void 0, void 0, function* () {
            return expect(__1.readPngFile(`this-file/does/not/exist.png`)).rejects.toBeTruthy();
        }));
    });
    describe("using the callback API", () => {
        it("decodes a PNG file", done => {
            __1.readPngFile(`${__dirname}/fixtures/orange-rectangle.png`, (error, pngImg) => {
                expect(error).toBeNull();
                utils_1.expectEveryPixel(pngImg.data, [255, 128, 64]);
                done();
            });
        });
        it("calls the callback with an error when decoding failed", done => {
            __1.readPngFile(`${__dirname}/fixtures/red-blue-gradient-256px.jpg`, (error, pngImg) => {
                expect(error).toMatchSnapshot();
                done();
            });
        });
        it("calls the callback with an error when reading failed", done => {
            __1.readPngFile(`this-file/does/not/exist.png`, (error, pngImg) => {
                expect(error).toBeTruthy();
                done();
            });
        });
    });
});
