"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const __1 = require("..");
const color_type_1 = require("../../color-type");
describe("General color utils", () => {
    describe("colorTypeToColorChecker", () => {
        it("returns the correct checker for `ColorType.GRAY_SCALE`", () => {
            expect(__1.colorTypeToColorChecker(color_type_1.ColorType.GRAY_SCALE)).toBe(__1.isColorGrayScale);
        });
        it("returns the correct checker for `ColorType.GRAY_SCALE_ALPHA`", () => {
            expect(__1.colorTypeToColorChecker(color_type_1.ColorType.GRAY_SCALE_ALPHA)).toBe(__1.isColorGrayScaleAlpha);
        });
        it("returns the correct checker for `ColorType.RGB`", () => {
            expect(__1.colorTypeToColorChecker(color_type_1.ColorType.RGB)).toBe(__1.isColorRGB);
        });
        it("returns the correct checker for `ColorType.RGBA`", () => {
            expect(__1.colorTypeToColorChecker(color_type_1.ColorType.RGBA)).toBe(__1.isColorRGBA);
        });
        it("returns the correct checker for `ColorType.PALETTE`", () => {
            expect(__1.colorTypeToColorChecker(color_type_1.ColorType.PALETTE)).toBe(__1.isColorPalette);
        });
        it("returns `undefined` for invalid input", () => {
            expect(__1.colorTypeToColorChecker(color_type_1.ColorType.UNKNOWN)).toBeUndefined();
        });
    });
    describe("defaultBackgroundColor", () => {
        it("returns the correct background color for `ColorType.GRAY_SCALE`", () => {
            expect(__1.defaultBackgroundColor(color_type_1.ColorType.GRAY_SCALE)).toEqual([255]);
        });
        it("returns the correct background color for `ColorType.GRAY_SCALE_ALPHA`", () => {
            expect(__1.defaultBackgroundColor(color_type_1.ColorType.GRAY_SCALE_ALPHA)).toEqual([0, 0]);
        });
        it("returns the correct background color for `ColorType.RGB`", () => {
            expect(__1.defaultBackgroundColor(color_type_1.ColorType.RGB)).toEqual([255, 255, 255]);
        });
        it("returns the correct background color for `ColorType.RGBA`", () => {
            expect(__1.defaultBackgroundColor(color_type_1.ColorType.RGBA)).toEqual([0, 0, 0, 0]);
        });
        it("returns the correct background color for `ColorType.PALETTE`", () => {
            expect(__1.defaultBackgroundColor(color_type_1.ColorType.PALETTE)).toEqual([0]);
        });
        it("returns `undefined` for invalid input", () => {
            expect(__1.defaultBackgroundColor(color_type_1.ColorType.UNKNOWN)).toBeUndefined();
        });
    });
});
