"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const palette_1 = require("../palette");
const gray_scale_1 = require("../gray-scale");
const rgb_1 = require("../rgb");
describe("The utilities for palette colors", () => {
    it("creates a gray scale alpha color", () => {
        const color = palette_1.colorPalette(4);
        expect(color.index).toBe(4);
        expect(color).toEqual([4]);
    });
    describe("checking if a given input is a palette color", () => {
        [
            undefined,
            null,
            10,
            "string",
            false,
            true,
            [],
            {},
            [1, 2],
            gray_scale_1.colorGrayScale(5),
        ].forEach(input => {
            it(`detects "${JSON.stringify(input)}" as false`, () => {
                expect(palette_1.isColorPalette(input)).toBe(false);
            });
        });
        it("detects a correct input as true", () => {
            expect(palette_1.isColorPalette(palette_1.colorPalette(4))).toBe(true);
        });
    });
    it("convert to RGBA", () => {
        const palette = new Map();
        palette.set(2, rgb_1.colorRGB(100, 90, 80));
        expect(palette_1.convertPaletteToRGBA(palette_1.colorPalette(2), palette)).toEqual([100, 90, 80, 255]);
    });
    it("convert to RGBA with invalid color in palette", () => {
        const palette = new Map();
        expect(palette_1.convertPaletteToRGBA(palette_1.colorPalette(3), palette)).toBeUndefined();
    });
});
