"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const rgba_1 = require("../rgba");
const rgb_1 = require("../rgb");
const gray_scale_1 = require("../gray-scale");
const gray_scale_alpha_1 = require("../gray-scale-alpha");
const palette_1 = require("../palette");
describe("The utilities for palette colors", () => {
    it("creates a gray scale alpha color", () => {
        const color = rgba_1.colorRGBA(50, 100, 150, 120);
        expect(color.r).toBe(50);
        expect(color.g).toBe(100);
        expect(color.b).toBe(150);
        expect(color.a).toBe(120);
        expect(color).toEqual([50, 100, 150, 120]);
    });
    describe("checking if a given input is a rgba color", () => {
        [
            undefined,
            null,
            10,
            "string",
            false,
            true,
            [],
            {},
            [1, 2],
            [1, 2, 3, 128],
            Object.assign([1, 2, 3, 128], { r: 1 }),
            Object.assign([1, 2, 3, 128], { r: 1, g: 2 }),
            Object.assign([1, 2, 3, 128], { r: 1, g: 2, b: 3 }),
            rgb_1.colorRGB(100, 120, 150),
        ].forEach(input => {
            it(`detects "${JSON.stringify(input)}" as false`, () => {
                expect(rgba_1.isColorRGBA(input)).toBe(false);
            });
        });
        it("detects a correct input as true", () => {
            expect(rgba_1.isColorRGBA(rgba_1.colorRGBA(40, 100, 120, 100))).toBe(true);
        });
    });
    describe("converting to RGBA", () => {
        it("converts a rgb color to rgba", () => {
            expect(rgba_1.convertToRGBA(rgb_1.colorRGB(1, 2, 3))).toEqual([1, 2, 3, 255]);
        });
        it("converts a gray scale color to rgba", () => {
            expect(rgba_1.convertToRGBA(gray_scale_1.colorGrayScale(1))).toEqual([1, 1, 1, 255]);
        });
        it("converts a gray scale alpha color to rgba", () => {
            expect(rgba_1.convertToRGBA(gray_scale_alpha_1.colorGrayScaleAlpha(1, 128))).toEqual([1, 1, 1, 128]);
        });
        it("converts a palette color to rgba", () => {
            const palette = new Map();
            palette.set(2, rgb_1.colorRGB(100, 90, 80));
            expect(rgba_1.convertToRGBA(palette_1.colorPalette(2), palette)).toEqual([100, 90, 80, 255]);
        });
        it("converts a rgba color to rgba", () => {
            expect(rgba_1.convertToRGBA(rgba_1.colorRGBA(1, 2, 3, 255))).toEqual([1, 2, 3, 255]);
        });
        it("returns `undefined` for invalid input", () => {
            expect(rgba_1.convertToRGBA(null)).toBeUndefined();
        });
    });
});
